@@ -1,7 +1,7 @@
 #ifndef SAFEMALLOC_H_HEADER_INCLUDED
 #define SAFEMALLOC_H_HEADER_INCLUDED
 
-#if defined(HAVE_MALLOC_H) && !defined(__OpenBSD__)
+#ifdef HAVE_MALLOC_H
 #include <malloc.h>
 #else
 #ifdef HAVE_STDLIB_H
